@@ -16,7 +16,7 @@ if not sys.stdin.isatty():
 	for line in sys.stdin:
 		id = line.strip().split()[0]  # first field
 		assert id.isdigit(), f'Bad card id {id}'
-		args.cards.append(Card(id))
+		args.cards.append(Card(int(id)))
 	# reconnect stdin to tty in case we used a pipe
 	sys.stdin = open('/dev/tty')  
 # operate on all the cards by default
@@ -24,11 +24,6 @@ if not args.cards:
 	args.cards = [Card(int(id.name)) for id in cards_path.iterdir()]
 
 	
-# run the specified function
-print(ansi['line_wrap_off'],end='')
-print(ansi['hide_cursor'],end='')
 func = args.func
 func = getattr(functions, func)
 func(args)
-print(ansi['show_cursor'],end='')
-print(ansi['line_wrap_on'], end='')
