@@ -2,7 +2,7 @@ import re
 import datetime
 TODAY = datetime.date.today()
 
-def filter_cards(cards, pattern='', 
+def filter(cards, pattern='', 
 	   tags_include={}, tags_exclude={}, # specify a SET of tags
 	   create_date_min=None, create_date_max=None,
 	   seen_date_min=None, seen_date_max=None,
@@ -17,7 +17,7 @@ def filter_cards(cards, pattern='',
 	# compile the regex pattern for faster searching
 	p = re.compile(f'({pattern})')  # wrap in parens to create regex group \1
 
-	f = lambda card: ((not tags_include or tags_include & card.tags) and
+	f = lambda card: (((not tags_include or tags_include & card.tags) and
 			(not tags_exclude or not tags_exclude & card.tags) and
 			(not create_date_min or create_date_min <= card.create_date) and
 			(not create_date_max or create_date_max >= card.create_date) and 
@@ -31,8 +31,7 @@ def filter_cards(cards, pattern='',
 			(not card.deleted or deleted_only or show_deleted) and
 			(card.deleted or not deleted_only) and
 			(not new_only or card.new) and
-			(not pattern or p.search(card.string)) and
-			(not due_only or card.due) ^
+			(not pattern or bool(p.search(card.string)))) != # TODO invert
 			invert)
 	
 	matches = [c for c in cards if f(c)]
