@@ -2,7 +2,6 @@ from vinca.lib.ansi import ansi
 import shutil
 
 COLUMNS, LINES = shutil.get_terminal_size()
-TAB_WIDTH = 8
 
 # A Context Manager for the terminal's alternate screen
 class AlternateScreen:
@@ -16,4 +15,5 @@ class AlternateScreen:
 
 	def __exit__(self, *exception_args):
 		print(ansi['restore_screen'],end='')
-		print(ansi['show_cursor'] + ansi['restore_cursor'],end='')
+		# print(ansi['show_cursor'] + ansi['restore_cursor'],end='')
+		print(ansi['restore_cursor'],end='')
