@@ -26,33 +26,27 @@ def date_type(arg):
 
 # argument parsing
 parser = argparse.ArgumentParser()
-parser.set_defaults(cards = [], func = 'statistics', generator = 'one_liner')
+parser.set_defaults(cards = [], func = 'statistics', generator = 'two_lines', review_date = TODAY, scrollback = False)
 subparsers = parser.add_subparsers()
 # commands which take a nothing as an argument
-one_liner = subparsers.add_parser('one_liner',aliases=['1'],
-	help='add a basic card quickly')
-one_liner.set_defaults(func = 'generate', generator = 'one_liner')
+two_lines = subparsers.add_parser('two_lines',aliases=['2'],
+	help='add a card quickly')
+two_lines.set_defaults(func = 'generate', generator = 'two_lines')
 
-linear_add = subparsers.add_parser('linear_add',aliases=['l'],
+verses = subparsers.add_parser('verses_add',aliases=['v'],
 	help='for lyrics, poetry, oratory, etc.')
-linear_add.set_defaults(func = 'generate', generator = 'linear')
+verses.set_defaults(func = 'generate', generator = 'verses')
 
-add= subparsers.add_parser('add_vim',aliases=['a'],
-	help='add a basic card')
-add.set_defaults(func = 'generate', generator = 'vim')
+media = subparsers.add_parser('media',aliases=['m'],
+	help='add a basic card with optional audio or images')
+media.set_defaults(func = 'generate', generator = 'media')
 
-add_many= subparsers.add_parser('add_many',aliases=['A'],
+add_many= subparsers.add_parser('add_many',aliases=['a'],
 	help='add several basic cards')
 add_many.set_defaults(func = 'add_many')
 
-
-image_cloze= subparsers.add_parser('image_cloze',aliases=['ic'],
-	help='generate an image cloze card')
-image_cloze.add_argument('image_path',type=Path)
-image_cloze.set_defaults(func = 'image_cloze')
-
 # filter
-filter= subparsers.add_parser('filter',aliases=['f'])
+filter= subparsers.add_parser('filter',aliases=['f'], help='')
 filter.add_argument('pattern',nargs='?',default='')
 # optional args of filter function
 filter.add_argument('-v','--invert',action='store_true')
@@ -74,57 +68,56 @@ filter.add_argument('--deleted_only',action='store_true')
 filter.add_argument('--show_deleted',action='store_true')
 filter.add_argument('--new_only',action='store_true')
 filter.add_argument('--not_new_only',action='store_true')
-filter.add_argument('--no_fancy',action='store_true')
 # other
 filter.add_argument('-i','--id_only',action='store_true')
 filter.set_defaults(func = 'display_filter')
 
-browse = subparsers.add_parser('browse', aliases=['b'])
+browse = subparsers.add_parser('browse', aliases=['b'], help='')
 browse.set_defaults(func = 'browse')
 
 # commands which take cards as an argument 
 review= subparsers.add_parser('review',aliases=['r'],
-	help='review the collection or selected card(s)')
+	help='')
 review.add_argument('cards', type=card_type, nargs='*')
-review.add_argument('--date', type=int,
+review.add_argument('--review_date', type=date_type, default=TODAY,
 	help='review as if today was [date]')
 review.set_defaults(func = 'review')
 
 statistics= subparsers.add_parser('statistics',aliases=['s'],
-	help='statistics about the selected cards')
+	help='')
 statistics.add_argument('cards', type=card_type, nargs='*')
 statistics.set_defaults(func = 'statistics')
 # TODO miscellaneous options for more advanced statistics
 edit= subparsers.add_parser('edit',aliases=['e'],
-	help='edit the selected card(s)')
+	help='')
 edit.add_argument('cards',type=card_type,nargs=1)
 edit.set_defaults(func = 'edit')
 
 edit_metadata= subparsers.add_parser('edit_metadata',aliases=['E'],
-	help='edit the selected card(s)')
+	help='')
 edit_metadata.add_argument('cards',type=card_type,nargs=1)
 edit_metadata.set_defaults(func = 'edit_metadata')
 
 delete= subparsers.add_parser('delete',aliases=['x'],
-	help='delete the selected card(s)')
+	help='')
 delete.add_argument('cards',type=card_type, nargs='*')
 delete.set_defaults(func = 'delete')
 
 # PURGE
 purge= subparsers.add_parser('purge',
-	help='permanently delete all deleted cards')
+	help='permanently delete cards')
 purge.set_defaults(func = 'purge')
 
 # commands which take a path as an argument (import / backup)
 # IMPORT EXPORT
 exp = subparsers.add_parser('export',
-	help='backup all cards')
+	help='')
 exp.add_argument('backup_dest',type=Path)
 exp.add_argument('cards',type=card_type,nargs='*') 
 exp.set_defaults(func = 'backup')
 
 imp = subparsers.add_parser('import',
-	help='import a collection of cards')
+	help='')
 imp.add_argument('import_path',type=Path)
 imp.add_argument('-o','--overwrite',action='store_true',
 	help='overwrite the existing collection')
